+{
   locale_version => 0.93,
   entry => <<'ENTRY', # for DUCET v6.2.0
00EA      ; [.164D.0020.0002.00EA] # LATIN SMALL LETTER E WITH CIRCUMFLEX
0065 0302 ; [.164D.0020.0002.00EA] # LATIN SMALL LETTER E WITH CIRCUMFLEX
00CA      ; [.164D.0020.0008.00CA] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
0045 0302 ; [.164D.0020.0008.00CA] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
1EC1      ; [.164D.0020.0002.00EA][.0000.0035.0002.0300] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
1EC0      ; [.164D.0020.0008.00CA][.0000.0035.0002.0300] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
1EBF      ; [.164D.0020.0002.00EA][.0000.0032.0002.0301] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
1EBE      ; [.164D.0020.0008.00CA][.0000.0032.0002.0301] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
1EC5      ; [.164D.0020.0002.00EA][.0000.004E.0002.0303] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE
1EC4      ; [.164D.0020.0008.00CA][.0000.004E.0002.0303] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE
1EC3      ; [.164D.0020.0002.00EA][.0000.0064.0002.0309] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
1EC2      ; [.164D.0020.0008.00CA][.0000.0064.0002.0309] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
1EC7      ; [.164D.0020.0002.00EA][.0000.0070.0002.0323] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW
1EC6      ; [.164D.0020.0008.00CA][.0000.0070.0002.0323] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW
00F4      ; [.1772.0020.0002.00F4] # LATIN SMALL LETTER O WITH CIRCUMFLEX
006F 0302 ; [.1772.0020.0002.00F4] # LATIN SMALL LETTER O WITH CIRCUMFLEX
00D4      ; [.1772.0020.0008.00D4] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX
004F 0302 ; [.1772.0020.0008.00D4] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX
1ED3      ; [.1772.0020.0002.00F4][.0000.0035.0002.0300] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE
1ED2      ; [.1772.0020.0008.00D4][.0000.0035.0002.0300] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE
1ED1      ; [.1772.0020.0002.00F4][.0000.0032.0002.0301] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE
1ED0      ; [.1772.0020.0008.00D4][.0000.0032.0002.0301] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE
1ED7      ; [.1772.0020.0002.00F4][.0000.004E.0002.0303] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE
1ED6      ; [.1772.0020.0008.00D4][.0000.004E.0002.0303] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE
1ED5      ; [.1772.0020.0002.00F4][.0000.0064.0002.0309] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
1ED4      ; [.1772.0020.0008.00D4][.0000.0064.0002.0309] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
1ED9      ; [.1772.0020.0002.00F4][.0000.0070.0002.0323] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW
1ED8      ; [.1772.0020.0008.00D4][.0000.0070.0002.0323] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW
0161      ; [.17F4.0020.0002.0161] # LATIN SMALL LETTER S WITH CARON
0073 030C ; [.17F4.0020.0002.0161] # LATIN SMALL LETTER S WITH CARON
0160      ; [.17F4.0020.0008.0160] # LATIN CAPITAL LETTER S WITH CARON
0053 030C ; [.17F4.0020.0008.0160] # LATIN CAPITAL LETTER S WITH CARON
ENTRY
};
