+{
   locale_version => 0.93,
   entry => <<'ENTRY', # for DUCET v6.2.0
0063 0068 ; [.161E.0020.0002.0063] # <LATIN SMALL LETTER C, LATIN SMALL LETTER H>
0043 0068 ; [.161E.0020.0007.0043] # <LATIN CAPITAL LETTER C, LATIN SMALL LETTER H>
0043 0048 ; [.161E.0020.0008.0043] # <LATIN CAPITAL LETTER C, LATIN CAPITAL LETTER H>
0064 0064 ; [.1632.0020.0002.0064] # <LATIN SMALL LETTER D, LATIN SMALL LETTER D>
0044 0064 ; [.1632.0020.0007.0044] # <LATIN CAPITAL LETTER D, LATIN SMALL LETTER D>
0044 0044 ; [.1632.0020.0008.0044] # <LATIN CAPITAL LETTER D, LATIN CAPITAL LETTER D>
0066 0066 ; [.1685.0020.0002.0066] # <LATIN SMALL LETTER F, LATIN SMALL LETTER F>
0046 0066 ; [.1685.0020.0007.0046] # <LATIN CAPITAL LETTER F, LATIN SMALL LETTER F>
0046 0046 ; [.1685.0020.0008.0046] # <LATIN CAPITAL LETTER F, LATIN CAPITAL LETTER F>
006E 0067 ; [.1692.0020.0002.006E] # <LATIN SMALL LETTER N, LATIN SMALL LETTER G>
004E 0067 ; [.1692.0020.0007.004E] # <LATIN CAPITAL LETTER N, LATIN SMALL LETTER G>
004E 0047 ; [.1692.0020.0008.004E] # <LATIN CAPITAL LETTER N, LATIN CAPITAL LETTER G>
006C 006C ; [.1712.0020.0002.006C] # <LATIN SMALL LETTER L, LATIN SMALL LETTER L>
004C 006C ; [.1712.0020.0007.004C] # <LATIN CAPITAL LETTER L, LATIN SMALL LETTER L>
004C 004C ; [.1712.0020.0008.004C] # <LATIN CAPITAL LETTER L, LATIN CAPITAL LETTER L>
0070 0068 ; [.1797.0020.0002.0070] # <LATIN SMALL LETTER P, LATIN SMALL LETTER H>
0050 0068 ; [.1797.0020.0007.0050] # <LATIN CAPITAL LETTER P, LATIN SMALL LETTER H>
0050 0048 ; [.1797.0020.0008.0050] # <LATIN CAPITAL LETTER P, LATIN CAPITAL LETTER H>
0072 0068 ; [.17BE.0020.0002.0072] # <LATIN SMALL LETTER R, LATIN SMALL LETTER H>
0052 0068 ; [.17BE.0020.0007.0052] # <LATIN CAPITAL LETTER R, LATIN SMALL LETTER H>
0052 0048 ; [.17BE.0020.0008.0052] # <LATIN CAPITAL LETTER R, LATIN CAPITAL LETTER H>
0074 0068 ; [.1817.0020.0002.0074] # <LATIN SMALL LETTER T, LATIN SMALL LETTER H>
0054 0068 ; [.1817.0020.0007.0054] # <LATIN CAPITAL LETTER T, LATIN SMALL LETTER H>
0054 0048 ; [.1817.0020.0008.0054] # <LATIN CAPITAL LETTER T, LATIN CAPITAL LETTER H>
ENTRY
};
