+{
   locale_version => 0.93,
   entry => <<'ENTRY', # for DUCET v6.2.0
0103      ; [.15F0.0020.0002.0103] # LATIN SMALL LETTER A WITH BREVE
0061 0306 ; [.15F0.0020.0002.0103] # LATIN SMALL LETTER A WITH BREVE
0102      ; [.15F0.0020.0008.0102] # LATIN CAPITAL LETTER A WITH BREVE
0041 0306 ; [.15F0.0020.0008.0102] # LATIN CAPITAL LETTER A WITH BREVE
1EB1      ; [.15F0.0020.0002.0103][.0000.0035.0002.0300] # LATIN SMALL LETTER A WITH BREVE AND GRAVE
1EB0      ; [.15F0.0020.0008.0102][.0000.0035.0002.0300] # LATIN CAPITAL LETTER A WITH BREVE AND GRAVE
1EAF      ; [.15F0.0020.0002.0103][.0000.0032.0002.0301] # LATIN SMALL LETTER A WITH BREVE AND ACUTE
1EAE      ; [.15F0.0020.0008.0102][.0000.0032.0002.0301] # LATIN CAPITAL LETTER A WITH BREVE AND ACUTE
1EB5      ; [.15F0.0020.0002.0103][.0000.004E.0002.0303] # LATIN SMALL LETTER A WITH BREVE AND TILDE
1EB4      ; [.15F0.0020.0008.0102][.0000.004E.0002.0303] # LATIN CAPITAL LETTER A WITH BREVE AND TILDE
1EB3      ; [.15F0.0020.0002.0103][.0000.0064.0002.0309] # LATIN SMALL LETTER A WITH BREVE AND HOOK ABOVE
1EB2      ; [.15F0.0020.0008.0102][.0000.0064.0002.0309] # LATIN CAPITAL LETTER A WITH BREVE AND HOOK ABOVE
1EB7      ; [.15F0.0020.0002.0103][.0000.0070.0002.0323] # LATIN SMALL LETTER A WITH BREVE AND DOT BELOW
1EB6      ; [.15F0.0020.0008.0102][.0000.0070.0002.0323] # LATIN CAPITAL LETTER A WITH BREVE AND DOT BELOW
00E2      ; [.15F1.0020.0002.00E2] # LATIN SMALL LETTER A WITH CIRCUMFLEX
0061 0302 ; [.15F1.0020.0002.00E2] # LATIN SMALL LETTER A WITH CIRCUMFLEX
00C2      ; [.15F1.0020.0008.00C2] # LATIN CAPITAL LETTER A WITH CIRCUMFLEX
0041 0302 ; [.15F1.0020.0008.00C2] # LATIN CAPITAL LETTER A WITH CIRCUMFLEX
1EA7      ; [.15F1.0020.0002.00E2][.0000.0035.0002.0300] # LATIN SMALL LETTER A WITH CIRCUMFLEX AND GRAVE
1EA6      ; [.15F1.0020.0008.00C2][.0000.0035.0002.0300] # LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND GRAVE
1EA5      ; [.15F1.0020.0002.00E2][.0000.0032.0002.0301] # LATIN SMALL LETTER A WITH CIRCUMFLEX AND ACUTE
1EA4      ; [.15F1.0020.0008.00C2][.0000.0032.0002.0301] # LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND ACUTE
1EAB      ; [.15F1.0020.0002.00E2][.0000.004E.0002.0303] # LATIN SMALL LETTER A WITH CIRCUMFLEX AND TILDE
1EAA      ; [.15F1.0020.0008.00C2][.0000.004E.0002.0303] # LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND TILDE
1EA9      ; [.15F1.0020.0002.00E2][.0000.0064.0002.0309] # LATIN SMALL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
1EA8      ; [.15F1.0020.0008.00C2][.0000.0064.0002.0309] # LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
1EAD      ; [.15F1.0020.0002.00E2][.0000.0070.0002.0323] # LATIN SMALL LETTER A WITH CIRCUMFLEX AND DOT BELOW
1EAC      ; [.15F1.0020.0008.00C2][.0000.0070.0002.0323] # LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND DOT BELOW
00EE      ; [.16CE.0020.0002.00EE] # LATIN SMALL LETTER I WITH CIRCUMFLEX
0069 0302 ; [.16CE.0020.0002.00EE] # LATIN SMALL LETTER I WITH CIRCUMFLEX
00CE      ; [.16CE.0020.0008.00CE] # LATIN CAPITAL LETTER I WITH CIRCUMFLEX
0049 0302 ; [.16CE.0020.0008.00CE] # LATIN CAPITAL LETTER I WITH CIRCUMFLEX
015F      ; [.17F4.0020.0002.015F] # LATIN SMALL LETTER S WITH CEDILLA
0073 0327 ; [.17F4.0020.0002.015F] # LATIN SMALL LETTER S WITH CEDILLA
0219      ; [.17F4.0020.0002.0219] # LATIN SMALL LETTER S WITH COMMA BELOW
0073 0326 ; [.17F4.0020.0002.0219] # LATIN SMALL LETTER S WITH COMMA BELOW
015E      ; [.17F4.0020.0008.015E] # LATIN CAPITAL LETTER S WITH CEDILLA
0053 0327 ; [.17F4.0020.0008.015E] # LATIN CAPITAL LETTER S WITH CEDILLA
0218      ; [.17F4.0020.0008.0218] # LATIN CAPITAL LETTER S WITH COMMA BELOW
0053 0326 ; [.17F4.0020.0008.0218] # LATIN CAPITAL LETTER S WITH COMMA BELOW
0163      ; [.1817.0020.0002.0163] # LATIN SMALL LETTER T WITH CEDILLA
0074 0327 ; [.1817.0020.0002.0163] # LATIN SMALL LETTER T WITH CEDILLA
021B      ; [.1817.0020.0002.021B] # LATIN SMALL LETTER T WITH COMMA BELOW
0074 0326 ; [.1817.0020.0002.021B] # LATIN SMALL LETTER T WITH COMMA BELOW
0162      ; [.1817.0020.0008.0162] # LATIN CAPITAL LETTER T WITH CEDILLA
0054 0327 ; [.1817.0020.0008.0162] # LATIN CAPITAL LETTER T WITH CEDILLA
021A      ; [.1817.0020.0008.021A] # LATIN CAPITAL LETTER T WITH COMMA BELOW
0054 0326 ; [.1817.0020.0008.021A] # LATIN CAPITAL LETTER T WITH COMMA BELOW
ENTRY
};
